@@ -1,11 +1,12 @@
 import json
 import logging
+from datetime import datetime
 from hashlib import sha256
 from pathlib import Path
 from typing import List, Optional, Union
 from urllib.parse import urljoin
 
-import dns.resolver
+import dns
 import requests
 
 from pkb_client.client import BindFile
@@ -16,7 +17,13 @@ from pkb_client.client.dns import (
     DNSRestoreMode,
 )
 from pkb_client.client.dnssec import DNSSECRecord
-from pkb_client.client.domain import DomainInfo
+from pkb_client.client.domain import (
+    DomainInfo,
+    DomainAvailability,
+    DomainCheckRateLimit,
+    DomainPrice,
+    GlueRecord,
+)
 from pkb_client.client.forwarding import URLForwarding, URLForwardingType
 from pkb_client.client.ssl_cert import SSLCertBundle
 
@@ -720,8 +727,18 @@ class PKBClient:
 
         if r.status_code == 200:
             return [
-                DomainInfo.from_dict(domain)
-                for domain in json.loads(r.text).get("domains", [])
+                DomainInfo(
+                    domain=d["domain"],
+                    status=d["status"],
+                    tld=d["tld"],
+                    create_date=datetime.fromisoformat(d["createDate"]),
+                    expire_date=datetime.fromisoformat(d["expireDate"]),
+                    security_lock=bool(d["securityLock"]),
+                    whois_privacy=bool(d["whoisPrivacy"]),
+                    auto_renew=bool(d["autoRenew"]),
+                    not_local=bool(d["notLocal"]),
+                )
+                for d in json.loads(r.text).get("domains", [])
             ]
         else:
             response_json = json.loads(r.text)
@@ -744,8 +761,15 @@ class PKBClient:
 
         if r.status_code == 200:
             return [
-                URLForwarding.from_dict(forwarding)
-                for forwarding in json.loads(r.text).get("forwards", [])
+                URLForwarding(
+                    id=f["id"],
+                    subdomain=f["subdomain"],
+                    location=f["location"],
+                    type=URLForwardingType[f["type"]],
+                    include_path=f["includePath"] == "yes",
+                    wildcard=f["wildcard"] == "yes",
+                )
+                for f in json.loads(r.text).get("forwards", [])
             ]
         else:
             response_json = json.loads(r.text)
@@ -885,7 +909,27 @@ class PKBClient:
 
         if r.status_code == 200:
             return [
-                DNSSECRecord.from_dict(record)
+                DNSSECRecord(
+                    key_tag=int(record["keyTag"]),
+                    alg=int(record["alg"]),
+                    digest_type=int(record["digestType"]),
+                    digest=record["digest"],
+                    max_sig_life=int(record["maxSigLife"])
+                    if "maxSigLife" in record
+                    else None,
+                    key_data_flags=int(record["keyDataFlags"])
+                    if "keyDataFlags" in record
+                    else None,
+                    key_data_protocol=int(record["keyDataProtocol"])
+                    if "keyDataProtocol" in record
+                    else None,
+                    key_data_algo=int(record["keyDataAlgo"])
+                    if "keyDataAlgo" in record
+                    else None,
+                    key_data_pub_key=record["keyDataPubKey"]
+                    if "keyDataPubKey" in record
+                    else None,
+                )
                 for record in json.loads(r.text).get("records", {}).values()
             ]
         else:
@@ -976,6 +1020,171 @@ class PKBClient:
                 response_json.get("message", "Unknown message"),
             )
 
+    def get_domain_availability(
+        self, domain: str
+    ) -> tuple[DomainAvailability, DomainCheckRateLimit]:
+        """
+        Check if a domain is available for registration and provide additional information about the domain like price
+        and if it is a premium domain.
+
+        Implements the API endpoint https://porkbun.com/api/json/v3/documentation#Domain%20Check
+
+        :param domain: the domain to check for availability
+        :return: DomainAvailability object and DomainCheckRateLimit object
+        :raises PKBClientException: if the API call was not successful
+        """
+
+        url = urljoin(self.api_endpoint, f"domain/checkDomain/{domain}")
+        r = requests.post(url=url, json=self._get_auth_request_json())
+
+        if r.status_code == 200:
+            data = json.loads(r.text)
+            response = data["response"]
+            limits = data["limits"]
+            return DomainAvailability(
+                available=response["avail"] == "yes",
+                type=response["type"],
+                price=float(response["price"]),
+                first_year_promo=response["firstYearPromo"] == "yes",
+                regular_price=float(response["regularPrice"]),
+                premium=response["premium"] == "yes",
+                additional_prices=[
+                    DomainPrice(
+                        type=ap["type"],
+                        price=float(ap["price"]),
+                        regular_price=float(ap["regularPrice"]),
+                    )
+                    for ap in response.get("additional", {}).values()
+                ],
+            ), DomainCheckRateLimit(
+                ttl=int(limits["TTL"]),
+                limit=int(limits["limit"]),
+                used=limits["used"],
+                natural_language=limits["naturalLanguage"],
+            )
+        else:
+            response_json = json.loads(r.text)
+            raise PKBClientException(
+                response_json.get("status", "Unknown status"),
+                response_json.get("message", "Unknown message"),
+            )
+
+    def get_glue_records(self, domain: str) -> list[GlueRecord]:
+        """Get all glue records for a specified domain.
+
+        Implements the API endpoint https://porkbun.com/api/json/v3/documentation#Domain%20Get%20Glue%20Records
+
+        :param domain: the domain for which the glue records should be retrieved
+        :return: list of GlueRecord objects
+        :raises PKBClientException: if the API call was not successful
+        """
+
+        url = urljoin(self.api_endpoint, f"domain/getGlue/{domain}")
+        req_json = self._get_auth_request_json()
+        r = requests.post(url=url, json=req_json)
+
+        if r.status_code == 200:
+            records = []
+
+            for host in json.loads(r.text).get("hosts", []):
+                v4 = host[1].get("v4")
+                v6 = host[1].get("v6")
+                record = GlueRecord(
+                    host=host[0],
+                    v4=v4[0] if v4 else None,
+                    v6=v6[0] if v6 else None,
+                )
+                records.append(record)
+
+            return records
+        response_json = json.loads(r.text)
+        raise PKBClientException(
+            response_json.get("status", "Unknown status"),
+            response_json.get("message", "Unknown message"),
+        )
+
+    def create_glue_record(
+        self, domain: str, glue_host_subdomain: str, ips: list[str]
+    ) -> bool:
+        """
+        Create a glue record for a specified domain and host.
+        Implements the API endpoint https://porkbun.com/api/json/v3/documentation#Domain%20Create%20Glue%20Record.
+
+        :param domain: the domain for which the glue record should be created
+        :param glue_host_subdomain: the subdomain of the glue record host, e.g. "ns1" for "ns1.example.com"
+        :param ips: list of IP addresses to create the glue record with
+        :return: True if everything went well
+        :raises PKBClientException: if the API call was not successful
+        """
+
+        url = urljoin(
+            self.api_endpoint,
+            f"domain/createGlue/{domain}/{glue_host_subdomain}",
+        )
+        req_json = {**self._get_auth_request_json(), "ips": ips}
+        r = requests.post(url=url, json=req_json)
+
+        if r.status_code == 200:
+            return True
+        response_json = json.loads(r.text)
+        raise PKBClientException(
+            response_json.get("status", "Unknown status"),
+            response_json.get("message", "Unknown message"),
+        )
+
+    def delete_glue_record(self, domain: str, glue_host_subdomain: str) -> bool:
+        """Delete a glue record for a specified domain and host specified by the subdomain of the glue record host.
+        Implements the API endpoint https://porkbun.com/api/json/v3/documentation#Domain%20Delete%20Glue%20Record.
+
+        :param domain: the domain for which the glue record should be deleted
+        :param glue_host_subdomain: the subdomain of the glue record host, e.g. "ns1" for "ns1.example.com"
+        :return: True if everything went well
+        :raises PKBClientException: if the API call was not successful
+        """
+
+        url = urljoin(
+            self.api_endpoint,
+            f"domain/deleteGlue/{domain}/{glue_host_subdomain}",
+        )
+        req_json = self._get_auth_request_json()
+        r = requests.post(url=url, json=req_json)
+
+        if r.status_code == 200:
+            return True
+        response_json = json.loads(r.text)
+        raise PKBClientException(
+            response_json.get("status", "Unknown status"),
+            response_json.get("message", "Unknown message"),
+        )
+
+    def update_glue_record(
+        self, domain: str, glue_host_subdomain: str, ips: list[str]
+    ) -> bool:
+        """Update a glue record for a specified domain and host.
+        Implements the API endpoint https://porkbun.com/api/json/v3/documentation#Domain%20Update%20Glue%20Record.
+
+        :param domain: the domain for which the glue record should be updated
+        :param glue_host_subdomain: the subdomain of the glue record host, e.g. "ns1" for "ns1.example.com"
+        :param ips: list of IP addresses to update the glue record with. Current IP addresses will be removed and replaced with these ones.
+        :return: True if everything went well
+        :raises PKBClientException: if the API call was not successful
+        """
+
+        url = urljoin(
+            self.api_endpoint,
+            f"domain/updateGlue/{domain}/{glue_host_subdomain}",
+        )
+        req_json = {**self._get_auth_request_json(), "ips": ips}
+        r = requests.post(url=url, json=req_json)
+
+        if r.status_code == 200:
+            return True
+        response_json = json.loads(r.text)
+        raise PKBClientException(
+            response_json.get("status", "Unknown status"),
+            response_json.get("message", "Unknown message"),
+        )
+
     @staticmethod
     def __handle_error_backup__(dns_records: list[DNSRecord]) -> None:
         """
