@@ -17,6 +17,11 @@ from pkb_client.client import (
 )
 from pkb_client.client.dns import DNSRecord, DNSRecordType
 from pkb_client.client.dnssec import DNSSECRecord
+from pkb_client.client.domain import (
+    DomainCheckRateLimit,
+    DomainAvailability,
+    DomainPrice,
+)
 from pkb_client.client.forwarding import URLForwarding, URLForwardingType
 
 
@@ -112,6 +117,90 @@ class TestClientAuth(unittest.TestCase):
             "example.com", DNSRecordType.MX, "127.0.0.1", "sub.example.com", 3600, 2
         )
 
+    @responses.activate
+    def test_create_https_record(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "dns/create/example.com"),
+            json={"status": "SUCCESS", "id": "345678"},
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "name": "example.com",
+                        "type": "HTTPS",
+                        "content": "1 . alpn=h2,h3",
+                        "ttl": 3600,
+                        "prio": None,
+                    }
+                )
+            ],
+        )
+        assert "345678" == pkb_client.create_dns_record(
+            "example.com", DNSRecordType.HTTPS, "1 . alpn=h2,h3", "example.com", 3600
+        )
+
+    @responses.activate
+    def test_create_sshfp_record(self):
+        pkb_client = PKBClient("key", "secret")
+
+        # SSHFP format: algorithm fp_type fingerprint (Ed25519 SHA-256)
+        responses.post(
+            url=urljoin(API_ENDPOINT, "dns/create/example.com"),
+            json={"status": "SUCCESS", "id": "456789"},
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "name": "example.com",
+                        "type": "SSHFP",
+                        "content": "4 2 abc123def456789",
+                        "ttl": 3600,
+                        "prio": None,
+                    }
+                )
+            ],
+        )
+        assert "456789" == pkb_client.create_dns_record(
+            "example.com",
+            DNSRecordType.SSHFP,
+            "4 2 abc123def456789",
+            "example.com",
+            3600,
+        )
+
+    @responses.activate
+    def test_create_svcb_record(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "dns/create/example.com"),
+            json={"status": "SUCCESS", "id": "567890"},
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "name": "_svc.example.com",
+                        "type": "SVCB",
+                        "content": "1 svc.example.com alpn=h2",
+                        "ttl": 3600,
+                        "prio": None,
+                    }
+                )
+            ],
+        )
+        assert "567890" == pkb_client.create_dns_record(
+            "example.com",
+            DNSRecordType.SVCB,
+            "1 svc.example.com alpn=h2",
+            "_svc.example.com",
+            3600,
+        )
+
     def test_create_dns_record_invalid_prio_record_type(self):
         pkb_client = PKBClient("key", "secret")
         with self.assertRaises(ValueError):
@@ -1173,7 +1262,7 @@ class TestClientAuth(unittest.TestCase):
         self.assertTrue(success)
 
     @responses.activate
-    def delete_dnssec_record(self):
+    def test_delete_dnssec_record(self):
         pkb_client = PKBClient("key", "secret")
 
         responses.post(
@@ -1189,6 +1278,393 @@ class TestClientAuth(unittest.TestCase):
         success = pkb_client.delete_dnssec_record("example.com", 123456)
         self.assertTrue(success)
 
+    @responses.activate
+    def test_get_domain_availability(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/checkDomain/example.com"),
+            json={
+                "status": "SUCCESS",
+                "response": {
+                    "avail": "no",
+                    "type": "registration",
+                    "price": "1.01",
+                    "firstYearPromo": "yes",
+                    "regularPrice": "11.82",
+                    "premium": "no",
+                    "additional": {
+                        "renewal": {
+                            "type": "renewal",
+                            "price": "11.82",
+                            "regularPrice": "11.82",
+                        },
+                        "transfer": {
+                            "type": "transfer",
+                            "price": "11.82",
+                            "regularPrice": "11.82",
+                        },
+                    },
+                },
+                "limits": {
+                    "TTL": "10",
+                    "limit": "1",
+                    "used": 1,
+                    "naturalLanguage": "1 out of 1 checks within 10 seconds used.",
+                },
+            },
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        domain_availability, domain_check_rate_limit = (
+            pkb_client.get_domain_availability("example.com")
+        )
+        expected_domain_availability = DomainAvailability(
+            available=False,
+            type="registration",
+            price=1.01,
+            first_year_promo=True,
+            regular_price=11.82,
+            premium=False,
+            additional_prices=[
+                DomainPrice(type="renewal", price=11.82, regular_price=11.82),
+                DomainPrice(type="transfer", price=11.82, regular_price=11.82),
+            ],
+        )
+        expected_domain_check_rate_limit = DomainCheckRateLimit(
+            ttl=10,
+            limit=1,
+            used=1,
+            natural_language="1 out of 1 checks within 10 seconds used.",
+        )
+        self.assertEqual(expected_domain_availability, domain_availability)
+        self.assertEqual(expected_domain_check_rate_limit, domain_check_rate_limit)
+
+    def test_get_domain_availability_rate_limited(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/checkDomain/example.com"),
+            json={
+                "message": "1 out of 1 checks within 10 seconds used.",
+                "status": "ERROR",
+            },
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        with self.assertRaises(PKBClientException) as context:
+            pkb_client.get_domain_availability("example.com")
+
+            self.assertIn(
+                "ERROR: 1 out of 1 checks within 10 seconds used.",
+                str(context.exception),
+            )
+
+    @responses.activate
+    def test_get_glue_records(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/getGlue/example.com"),
+            json={
+                "status": "SUCCESS",
+                "hosts": [
+                    ["ns1.example.com", {"v6": ["2001:db8::1"], "v4": ["192.168.1.1"]}],
+                    ["ns2.example.com", {"v6": ["2001:db8::2"], "v4": ["192.168.1.2"]}],
+                ],
+            },
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        glue_records = pkb_client.get_glue_records("example.com")
+
+        self.assertEqual(2, len(glue_records))
+        self.assertEqual("ns1.example.com", glue_records[0].host)
+        self.assertEqual("192.168.1.1", glue_records[0].v4)
+        self.assertEqual("2001:db8::1", glue_records[0].v6)
+        self.assertEqual("ns2.example.com", glue_records[1].host)
+        self.assertEqual("192.168.1.2", glue_records[1].v4)
+        self.assertEqual("2001:db8::2", glue_records[1].v6)
+
+    @responses.activate
+    def test_get_glue_records_empty(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/getGlue/example.com"),
+            json={
+                "status": "SUCCESS",
+                "hosts": {},
+            },
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        glue_records = pkb_client.get_glue_records("example.com")
+
+        self.assertEqual(0, len(glue_records))
+
+    @responses.activate
+    def test_get_glue_records_partial_data(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/getGlue/example.com"),
+            json={
+                "status": "SUCCESS",
+                "hosts": [["ns1.example.com", {"v6": [], "v4": ["192.168.1.1"]}]],
+            },
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        glue_records = pkb_client.get_glue_records("example.com")
+
+        self.assertEqual(1, len(glue_records))
+        self.assertEqual("ns1.example.com", glue_records[0].host)
+        self.assertEqual("192.168.1.1", glue_records[0].v4)
+        self.assertEqual(None, glue_records[0].v6)
+
+    @responses.activate
+    def test_get_glue_records_error(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/getGlue/example.com"),
+            json={
+                "status": "ERROR",
+                "message": "Domain does not exist",
+            },
+            status=400,
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        with self.assertRaises(PKBClientException) as context:
+            pkb_client.get_glue_records("example.com")
+
+        self.assertIn(
+            "ERROR: Domain does not exist",
+            str(context.exception),
+        )
+
+    @responses.activate
+    def test_delete_glue_record(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/deleteGlue/example.com/ns1"),
+            json={"status": "SUCCESS"},
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        success = pkb_client.delete_glue_record("example.com", "ns1")
+
+        self.assertTrue(success)
+
+    @responses.activate
+    def test_delete_glue_record_error(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/deleteGlue/example.com/ns1"),
+            json={
+                "status": "ERROR",
+                "message": "Glue record not found",
+            },
+            status=400,
+            match=[
+                matchers.json_params_matcher(
+                    {"apikey": "key", "secretapikey": "secret"}
+                )
+            ],
+        )
+
+        with self.assertRaises(PKBClientException) as context:
+            pkb_client.delete_glue_record("example.com", "ns1")
+
+        self.assertIn(
+            "ERROR: Glue record not found",
+            str(context.exception),
+        )
+
+    @responses.activate
+    def test_create_glue_record(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/createGlue/example.com/ns1"),
+            json={"status": "SUCCESS"},
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "ips": ["192.0.2.1", "2001:db8::1"],
+                    }
+                )
+            ],
+        )
+
+        success = pkb_client.create_glue_record(
+            "example.com", "ns1", ["192.0.2.1", "2001:db8::1"]
+        )
+
+        self.assertTrue(success)
+
+    @responses.activate
+    def test_create_glue_record_single_ip(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/createGlue/example.com/ns1"),
+            json={"status": "SUCCESS"},
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "ips": ["192.0.2.1"],
+                    }
+                )
+            ],
+        )
+
+        success = pkb_client.create_glue_record("example.com", "ns1", ["192.0.2.1"])
+
+        self.assertTrue(success)
+
+    @responses.activate
+    def test_create_glue_record_error(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/createGlue/example.com/ns1"),
+            json={
+                "status": "ERROR",
+                "message": "Invalid IP address format",
+            },
+            status=400,
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "ips": ["invalid.ip.address"],
+                    }
+                )
+            ],
+        )
+
+        with self.assertRaises(PKBClientException) as context:
+            pkb_client.create_glue_record("example.com", "ns1", ["invalid.ip.address"])
+
+        self.assertIn(
+            "ERROR: Invalid IP address format",
+            str(context.exception),
+        )
+
+    @responses.activate
+    def test_update_glue_record(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/updateGlue/example.com/ns1"),
+            json={"status": "SUCCESS"},
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "ips": ["192.0.2.1", "2001:db8::1"],
+                    }
+                )
+            ],
+        )
+
+        success = pkb_client.update_glue_record(
+            "example.com", "ns1", ["192.0.2.1", "2001:db8::1"]
+        )
+
+        self.assertTrue(success)
+
+    @responses.activate
+    def test_update_glue_record_single_ip(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/updateGlue/example.com/ns1"),
+            json={"status": "SUCCESS"},
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "ips": ["192.0.2.1"],
+                    }
+                )
+            ],
+        )
+
+        success = pkb_client.update_glue_record("example.com", "ns1", ["192.0.2.1"])
+
+        self.assertTrue(success)
+
+    @responses.activate
+    def test_update_glue_record_error(self):
+        pkb_client = PKBClient("key", "secret")
+
+        responses.post(
+            url=urljoin(API_ENDPOINT, "domain/updateGlue/example.com/ns1"),
+            json={
+                "status": "ERROR",
+                "message": "Invalid IP address format",
+            },
+            status=400,
+            match=[
+                matchers.json_params_matcher(
+                    {
+                        "apikey": "key",
+                        "secretapikey": "secret",
+                        "ips": ["invalid.ip.address"],
+                    }
+                )
+            ],
+        )
+
+        with self.assertRaises(PKBClientException) as context:
+            pkb_client.update_glue_record("example.com", "ns1", ["invalid.ip.address"])
+
+        self.assertIn(
+            "ERROR: Invalid IP address format",
+            str(context.exception),
+        )
+
 
 if __name__ == "__main__":
     unittest.main()
